@@ -1,4 +1,4 @@
-#' Parse and examine further GBIF issues on a dataset
+#' Parse and examine further GBIF occurrence issues on a dataset.
 #'
 #' @export
 #'
@@ -7,15 +7,14 @@
 #' otherwise function stops with error. The data from `occ_download_import`
 #' is just a regular data.frame so you can pass in a data.frame to this
 #' function, but if it doesn't have certain columns it will fail.
-#' @param ... Named parameters to only get back (e.g., cdround), or to
+#' @param ... Named parameters to only get back (e.g. cdround), or to
 #' remove (e.g. -cdround).
 #' @param mutate (character) One of:
-#'
-#' - `split` Split issues into new columns
-#' - `split_expand` Split into new columns, and expand issue names
+#' - `split` Split issues into new columns.
 #' - `expand` Expand issue abbreviated codes into descriptive names.
 #' for downloads datasets, this is not super useful since the
 #' issues come to you as expanded already.
+#' - `split_expand` Split into new columns, and expand issue names.
 #'
 #' For split and split_expand, values in cells become y ("yes") or n ("no")
 #'
@@ -33,15 +32,18 @@
 #' This function only affects the `data` element in the `gbif` class that is
 #' returned from a call to [occ_search()]. Maybe in a future version
 #' we will remove the associated records from the `hierarchy` and `media`
-#' elements as they are remove from the `data` element.
+#' elements as they are removed from the `data` element.
 #'
 #' You'll notice that we sort columns to make it easier to glimpse the important
 #' parts of your data, namely taxonomic name, taxon key, latitude and longitude,
 #' and the issues. The columns are unchanged otherwise.
 #'
 #' @examples \dontrun{
-#' ## what do issues mean, can print whole table, or search for matches
+#' # what do issues mean, can print whole table
 #' head(gbif_issues())
+#' # or just occurrence related issues
+#' gbif_issues()[which(gbif_issues()$type %in% c("occurrence")),]
+#' # or search for matches
 #' iss <- c('cdround','cudc','gass84','txmathi')
 #' gbif_issues()[ gbif_issues()$code %in% iss, ]
 #'
@@ -55,11 +57,11 @@
 #'
 #' # Parsing output by issue
 #' (res <- occ_data(
-#'   geometry='POLYGON((30.1 10.1, 10 20, 20 40, 40 40, 30.1 10.1))',
+#'   geometry='POLYGON((30.1 10.1,40 40,20 40,10 20,30.1 10.1))',
 #'   limit = 600))
 #'
 #' ## or parse issues in various ways
-#' ### inlude only rows with cdround issue
+#' ### include only rows with cdround issue
 #' gg <- res %>% occ_issues(cdround)
 #' NROW(res$data)
 #' NROW(gg$data)
@@ -83,10 +85,10 @@
 #' ### split, expand, and remove an issue class
 #' res %>% occ_issues(-cdround, mutate = "split_expand")
 #'
-#' ## Or you can use occ_issues without the pipe
+#' ## Or you can use occ_issues without %>%
 #' occ_issues(res, -cdround, mutate = "split_expand")
 #'
-#' # from GBIF downloaded data via occ_download and friends
+#' # from GBIF downloaded data via occ_download_* functions
 #' res <- occ_download_get(key="0000066-140928181241064", overwrite=TRUE)
 #' x <- occ_download_import(res)
 #' occ_issues(x, -txmathi)
@@ -113,110 +115,7 @@
 occ_issues <- function(.data, ..., mutate = NULL) {
   assert(.data, c("gbif", "gbif_data", "data.frame", "tbl_df"))
 
-  if ("data" %in% names(.data)) {
-    tmp <- .data$data
-  } else {
-    many <- FALSE
-    if (attr(.data, "type") %||% "" == "many") {
-      many <- TRUE
-      tmp <- data.table::setDF(
-        data.table::rbindlist(lapply(.data, "[[", "data"),
-          fill = TRUE, use.names = TRUE, idcol = "ind"))
-    } else {
-      tmp <- .data
-    }
-  }
+  check_issues(type = "occurrence", ...)
 
-  # handle downloads data
-  is_dload <- FALSE
-  if (
-    all(
-      c("issue", "gbifID", "accessRights", "accrualMethod") %in% names(tmp)
-    ) &&
-    !"issues" %in% names(tmp)
-  ) {
-    is_dload <- TRUE
-
-    # convert long issue names to short ones
-    issstr <- tmp[names(tmp) %in% "issue"][[1]]
-    tmp$issues <- unlist(lapply(issstr, function(z) {
-      if (identical(z, "")) return (character(1))
-      paste(gbifissues[ grepl(gsub(";", "|", z), gbifissues$issue), "code" ],
-        collapse = ",")
-    }))
-  }
-
-  if (!length(dots(...)) == 0) {
-    filters <- parse_input(...)
-    if (length(filters$neg) > 0) {
-      tmp <- tmp[ !grepl(paste(filters$neg, collapse = "|"), tmp$issues), ]
-    }
-    if (length(filters$pos) > 0) {
-      tmp <- tmp[ grepl(paste(filters$pos, collapse = "|"), tmp$issues), ]
-    }
-  }
-
-  if (!is.null(mutate)) {
-    if (mutate == "split") {
-      tmp <- split_iss(tmp, is_dload)
-    } else if (mutate == "split_expand") {
-      tmp <- mutate_iss(tmp)
-      tmp <- split_iss(tmp, is_dload)
-    } else if (mutate == "expand") {
-      tmp <- mutate_iss(tmp)
-    }
-  }
-
-  if ("data" %in% names(.data)) {
-    .data$data <- tmp
-    return( .data )
-  } else if (many) {
-    tmpsplit <- split(tmp, tmp$ind)
-    for (i in seq_along(names(.data))) {
-      df <- tibble::as_tibble(tmpsplit[[ names(.data)[i] ]])
-      if (NROW(df) > 0) df$ind <- NULL
-      .data[[ names(.data)[i] ]]$data <- df
-    }
-    return(.data)
-  } else {
-    return( tmp )
-  }
-}
-
-mutate_iss <- function(w) {
-  w$issues <- sapply(strsplit(w$issues, split = ","), function(z) {
-    paste(gbifissues[ gbifissues$code %in% z, "issue" ], collapse = ",")
-  })
-  return( w )
-}
-
-split_iss <- function(m, is_dload) {
-  unq <- unique(unlist(strsplit(m$issues, split = ",")))
-  df <- data.table::setDF(
-    data.table::rbindlist(
-      lapply(strsplit(m$issues, split = ","), function(b) {
-        v <- unq %in% b
-        data.frame(rbind(ifelse(v, "y", "n")), stringsAsFactors = FALSE)
-      })
-    )
-  )
-  names(df) <- unq
-  m$issues <- NULL
-  first_search <- c("name", "key", "decimalLatitude", "decimalLongitude")
-  first_dload <- c("scientificName", "taxonKey", "decimalLatitude",
-    "decimalLongitude")
-  first <- if (is_dload) first_dload else first_search
-  tibble::as_tibble(data.frame(m[, first], df, m[, !names(m) %in% first],
-    stringsAsFactors = FALSE))
-}
-
-parse_input <- function(...) {
-  x <- as.character(dots(...))
-  neg <- gsub("-", "", x[grepl("-", x)])
-  pos <- x[!grepl("-", x)]
-  list(neg = neg, pos = pos)
-}
-
-dots <- function(...){
-  eval(substitute(alist(...)))
+  handle_issues(.data, is_occ = TRUE, ..., mutate = mutate)
 }
