@@ -182,7 +182,7 @@ test_that("scientificName basic use works - no synonyms", {
 
   expect_equal(attr(bb, "args")$scientificName, "Pulsatilla patens")
   expect_equal(bb$data$species[1], "Pulsatilla patens")
-  bb_sc_nam <- "Anemone patens subsp. multifida (Pritzel) Hult\u00e9n"
+  bb_sc_nam <- "Pulsatilla nuttalliana (DC.) Spreng."
   expect_equal(bb$data$scientificName[1],
                bb_sc_nam)
 
@@ -330,29 +330,6 @@ test_that("geometry inputs work as expected", {
 })
 
 
-######### spell check works
-test_that("spell check param works", {
-  vcr::use_cassette("occ_search_spell_check", {
-    # as normal
-    expect_is(
-      occ_search(search = "kingfisher", limit=1, spellCheck = TRUE),
-      "gbif"
-    )
-
-    # spelled incorrectly - stops with suggested spelling
-    expect_error(
-      occ_search(search = "kajsdkla", limit=20, spellCheck = TRUE),
-      "spelling bad - suggestions"
-    )
-
-    # spelled incorrectly - stops with many suggested spellings and number of results for each
-    expect_error(
-      occ_search(search = "helir", limit=20, spellCheck = TRUE),
-      "spelling bad - suggestions"
-    )
-  })
-})
-
 # many args
 test_that("works with parameters that allow many inputs", {
   vcr::use_cassette("occ_search_many_inputs", {
